==> zerochplus_0.5.10.zip: zerochplus_0.5.10/test/plugin/0ch_spamblock.pl <==
#============================================================================================================
#
#	g@\ - oXpLZ[I
#	0ch_spam_block.pl
#
#	by windyakin windyaking
#
#	http://windyakin.net/
#
#	---------------------------------------------------------------------------
#
#	2010.06.17 start
#
#============================================================================================================
package ZPL_spamblock;

#------------------------------------------------------------------------------------------------------------
#
#	RXgN^
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	IuWFNg
#
#------------------------------------------------------------------------------------------------------------
sub new
{
	my $this = shift;
	my $obj={};
	bless($obj,$this);
	return $obj;
}

#------------------------------------------------------------------------------------------------------------
#
#	g@\̎擾
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	̕
#
#------------------------------------------------------------------------------------------------------------
sub getName
{
	my	$this = shift;
	return 'oXpLZ[';
}

#------------------------------------------------------------------------------------------------------------
#
#	g@\擾
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	
#
#------------------------------------------------------------------------------------------------------------
sub getExplanation
{
	my	$this = shift;
	return 'URL𒲂ׂĉ͂܂';
}

#------------------------------------------------------------------------------------------------------------
#
#	g@\^Cv擾
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	g@\^Cv(X:1,X:2,read:4,index:8)
#
#------------------------------------------------------------------------------------------------------------
sub getType
{
	my	$this = shift;
	return (1 | 2);
}

#------------------------------------------------------------------------------------------------------------
#
#	g@\sC^tFCX
#	-------------------------------------------------------------------------------------
#	@param	$sys	MELKOR
#	@param	$form	SAMWISE
#	@return	Ȉꍇ0
#
#------------------------------------------------------------------------------------------------------------
sub execute
{
	my $this = shift;
	my ($sys, $form) = @_;
	
	# bZ[W擾
	my $mes = $form->Get('MESSAGE');
	
	# Encode.pm̎g킩Ȃł
	use Encode;
	Encode::from_to( $mes, "Shift_JIS", "UTF-8" );
	
	if ( $mes =~ /(h?ttp:\/\/)?([0-9a-zA-Z\.-]+\.(?:com|net|org|biz|info|me))/ ) {
		
		# zXg𒲍
		my $bin_addr = gethostbyname($2);
		my $result = sprintf("%vd", $bin_addr);
		
		# G[Ԃ
		if ( $result eq "66.71.248.210" ) {
			&PrintBBSError ( $sys, $form, 205 )
		}
		
	}
	
	return 0;
}

#------------------------------------------------------------------------------------------------------------
#
#	Ȃ񂿂bbs.cgiG[y[W\
#	-------------------------------------------------------------------------------------
#	@param	$sys	MELKOR
#	@param	$form	SAMWISE
#	@param	$err	G[ԍ
#	@return	Ȃ
#	exit	G[ԍ
#
#------------------------------------------------------------------------------------------------------------
sub PrintBBSError
{
	my ($sys,$form,$err) = @_;
	my $SYS;
	
	require('./module/radagast.pl');
	require('./module/isildur.pl');
	require('./module/thorin.pl');
	
	$SYS->{'SYS'}		= $sys;
	$SYS->{'FORM'}		= $form;
	$SYS->{'COOKIE'}	= new RADAGAST;
	$SYS->{'COOKIE'}->Init();
	$SYS->{'SET'}		= new ISILDUR;
	$SYS->{'SET'}->Load($sys);
	my $Page = new THORIN;
	
	require('./module/orald.pl');
	$ERROR = new ORALD;
	$ERROR->Load($sys);
	
	$ERROR->Print($SYS,$Page,$err,$sys->Get('AGENT'));
	
	$Page->Flush('',0,0);
	
	exit($err);
}

#============================================================================================================
#	Module END
#============================================================================================================
1;
__END__

==> zerochplus_0.7.4.zip: zerochplus_0.7.4/test/plugin/0ch_spamblock.pl <==
#============================================================================================================
#
#	g@\ - oXpLZ[I
#	0ch_spam_block.pl
#
#	by windyakin windyaking
#
#	http://windyakin.net/
#
#	---------------------------------------------------------------------------
#
#	2010.06.17 start
#
#============================================================================================================
package ZPL_spamblock;

#------------------------------------------------------------------------------------------------------------
#
#	RXgN^
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	IuWFNg
#
#------------------------------------------------------------------------------------------------------------
sub new
{
	my $this = shift;
	my $obj={};
	bless($obj,$this);
	return $obj;
}

#------------------------------------------------------------------------------------------------------------
#
#	g@\̎擾
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	̕
#
#------------------------------------------------------------------------------------------------------------
sub getName
{
	my	$this = shift;
	return 'oXpLZ[';
}

#------------------------------------------------------------------------------------------------------------
#
#	g@\擾
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	
#
#------------------------------------------------------------------------------------------------------------
sub getExplanation
{
	my	$this = shift;
	return 'URL𒲂ׂĉ͂܂';
}

#------------------------------------------------------------------------------------------------------------
#
#	g@\^Cv擾
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	g@\^Cv(X:1,X:2,read:4,index:8)
#
#------------------------------------------------------------------------------------------------------------
sub getType
{
	my	$this = shift;
	return (1 | 2);
}

#------------------------------------------------------------------------------------------------------------
#
#	g@\sC^tFCX
#	-------------------------------------------------------------------------------------
#	@param	$sys	MELKOR
#	@param	$form	SAMWISE
#	@return	Ȉꍇ0
#
#------------------------------------------------------------------------------------------------------------
sub execute
{
	my $this = shift;
	my ($sys, $form) = @_;
	my ( @ng_addr, $mes, $bin_addr, $result );
	
	# ֎~IPAhX
	@ng_addr  = ( '66.71.248.210', '174.122.102.1', '74.207.244.52', '74.207.242.227' );
	
	# bZ[W擾
	$mes = $form->Get('MESSAGE');
	
	# Encode.pm̎g킩Ȃł
	require Encode;
	Encode::from_to( $mes, "Shift_JIS", "UTF-8" );
	
	while ( $mes =~ /(h?ttp:\/\/)?([0-9a-zA-Z\.\-]+\.(?:com|net|info|me|mobi|cc|asia|org|biz|co|in|tv|ch|at|mn|la|vg|ms|gs|vc|bz|ws|be|so))/ig )
	{
		
		# zXg𒲍
		$bin_addr = gethostbyname($2);
		$result = sprintf("%vd", $bin_addr);
		
		# G[Ԃ
		foreach ( @ng_addr ) {
			if ( $_ eq $result ) {
				PrintBBSError( $sys, $form, 205 );
			}
		}
		
	}
	
	return 0;
}

#------------------------------------------------------------------------------------------------------------
#
#	Ȃ񂿂bbs.cgiG[y[W\
#	-------------------------------------------------------------------------------------
#	@param	$sys	MELKOR
#	@param	$form	SAMWISE
#	@param	$err	G[ԍ
#	@return	Ȃ
#	exit	G[ԍ
#
#------------------------------------------------------------------------------------------------------------
sub PrintBBSError
{
	my ($sys,$form,$err) = @_;
	my $SYS;
	
	require('./module/radagast.pl');
	require('./module/isildur.pl');
	require('./module/thorin.pl');
	
	$SYS->{'SYS'}		= $sys;
	$SYS->{'FORM'}		= $form;
	$SYS->{'COOKIE'}	= new RADAGAST;
	$SYS->{'COOKIE'}->Init();
	$SYS->{'SET'}		= new ISILDUR;
	$SYS->{'SET'}->Load($sys);
	my $Page = new THORIN;
	
	require('./module/orald.pl');
	$ERROR = new ORALD;
	$ERROR->Load($sys);
	
	$ERROR->Print($SYS,$Page,$err,$sys->Get('AGENT'));
	
	$Page->Flush('',0,0);
	
	exit($err);
}

#============================================================================================================
#	Module END
#============================================================================================================
1;
__END__
